@@ -220,6 +220,7 @@
 #define ZOMATCOPY_K_CTC         zomatcopy_k_ctc
 #define ZOMATCOPY_K_RTC         zomatcopy_k_rtc
 
+#define ZGEADD_K                zgeadd_k 
 
 #else
 
@@ -403,6 +404,8 @@
 #define ZOMATCOPY_K_CTC         gotoblas -> zomatcopy_k_ctc
 #define ZOMATCOPY_K_RTC         gotoblas -> zomatcopy_k_rtc
 
+#define ZGEADD_K                gotoblas -> zgeadd_k
+
 #endif
 
 #define	ZGEMM_NN		zgemm_nn
