@@ -48,6 +48,12 @@
 #define SWITCH_RATIO 2
 #endif
 
+//The array of job_t may overflow the stack.
+//Instead, use malloc to alloc job_t.
+#if MAX_CPU_NUMBER > BLAS3_MEM_ALLOC_THRESHOLD
+#define USE_ALLOC_HEAP
+#endif
+
 #ifndef GEMM3M_LOCAL
 #if   defined(NN)
 #define GEMM3M_LOCAL    GEMM3M_NN
@@ -356,12 +362,12 @@ static int inner_thread(blas_arg_t *args, BLASLONG *range_m, BLASLONG *range_n,
 #endif
 
   div_n = (n_to - n_from + DIVIDE_RATE - 1) / DIVIDE_RATE;
-  
+
   buffer[0] = sb;
   for (i = 1; i < DIVIDE_RATE; i++) {
     buffer[i] = buffer[i - 1] + GEMM3M_Q * ((div_n + GEMM3M_UNROLL_N - 1) & ~(GEMM3M_UNROLL_N - 1));
   }
-  
+
   for(ls = 0; ls < k; ls += min_l){
     min_l = k - ls;
     if (min_l >= GEMM3M_Q * 2) {
@@ -373,7 +379,7 @@ static int inner_thread(blas_arg_t *args, BLASLONG *range_m, BLASLONG *range_n,
     }
 
     min_i = m_to - m_from;
-    
+
     if (min_i >= GEMM3M_P * 2) {
       min_i = GEMM3M_P;
     } else {
@@ -384,73 +390,73 @@ static int inner_thread(blas_arg_t *args, BLASLONG *range_m, BLASLONG *range_n,
 
 
     START_RPCC();
-    
+
     ICOPYB_OPERATION(min_l, min_i, a, lda, ls, m_from, sa);
-    
+
     STOP_RPCC(copy_A);
-    
+
     div_n = (n_to - n_from + DIVIDE_RATE - 1) / DIVIDE_RATE;
-    
+
     for (xxx = n_from, bufferside = 0; xxx < n_to; xxx += div_n, bufferside ++) {
-      
+
       START_RPCC();
-      
+
       /* Make sure if no one is using another buffer */
       for (i = 0; i < args -> nthreads; i++)
 	while (job[mypos].working[i][CACHE_LINE_SIZE * bufferside]) {YIELDING;};
-      
+
       STOP_RPCC(waiting1);
-      
+
       for(jjs = xxx; jjs < MIN(n_to, xxx + div_n); jjs += min_jj){
 	min_jj = MIN(n_to, xxx + div_n) - jjs;
 	if (min_jj > GEMM3M_UNROLL_N) min_jj = GEMM3M_UNROLL_N;
-	
+
 	START_RPCC();
-	
+
 #if defined(NN) || defined(NT) || defined(TN) || defined(TT) || defined(RN) || defined(RT) || defined(CN) || defined(CT)
 	OCOPYB_OPERATION(min_l, min_jj, b, ldb, alpha[0],  alpha[1], ls, jjs, buffer[bufferside] + min_l * (jjs - xxx));
 #else
 	OCOPYB_OPERATION(min_l, min_jj, b, ldb, alpha[0], -alpha[1], ls, jjs, buffer[bufferside] + min_l * (jjs - xxx));
 #endif
-	
+
 	STOP_RPCC(copy_B);
-	
+
 	START_RPCC();
-	
+
 	  KERNEL_OPERATION(min_i, min_jj, min_l, ALPHA5, ALPHA6,
 			   sa, buffer[bufferside] + min_l * (jjs - xxx),
 			   c, ldc, m_from, jjs);
-	  
+
 	STOP_RPCC(kernel);
 #ifdef TIMING
 	  ops += 2 * min_i * min_jj * min_l;
 #endif
 
       }
-	
+
       for (i = 0; i < args -> nthreads; i++)
 	job[mypos].working[i][CACHE_LINE_SIZE * bufferside] = (BLASLONG)buffer[bufferside];
       }
-    
+
     current = mypos;
-    
+
     do {
       current ++;
       if (current >= args -> nthreads) current = 0;
-      
+
       div_n = (range_n[current + 1]  - range_n[current] + DIVIDE_RATE - 1) / DIVIDE_RATE;
-      
+
       for (xxx = range_n[current], bufferside = 0; xxx < range_n[current + 1]; xxx += div_n, bufferside ++) {
-	
+
 	if (current != mypos) {
-	  
+
 	  START_RPCC();
-	  
+
 	  /* thread has to wait */
 	  while(job[current].working[mypos][CACHE_LINE_SIZE * bufferside] == 0) {YIELDING;};
-	  
+
 	  STOP_RPCC(waiting2);
-	    
+
 	  START_RPCC();
 
 
@@ -463,42 +469,42 @@ static int inner_thread(blas_arg_t *args, BLASLONG *range_m, BLASLONG *range_n,
 	  ops += 2 * min_i * MIN(range_n[current + 1]  - xxx,  div_n) * min_l;
 #endif
 	}
-	
+
 	if (m_to - m_from == min_i) {
 	  job[current].working[mypos][CACHE_LINE_SIZE * bufferside] = 0;
 	}
       }
     } while (current != mypos);
-    
+
     for(is = m_from + min_i; is < m_to; is += min_i){
       min_i = m_to - is;
       if (min_i >= GEMM3M_P * 2) {
 	min_i = GEMM3M_P;
-      } else 
+      } else
 	if (min_i > GEMM3M_P) {
 	  min_i = ((min_i + 1) / 2 + GEMM3M_UNROLL_M - 1) & ~(GEMM3M_UNROLL_M - 1);
 	}
-      
+
       START_RPCC();
-      
+
       ICOPYB_OPERATION(min_l, min_i, a, lda, ls, is, sa);
-      
+
       STOP_RPCC(copy_A);
-      
+
       current = mypos;
       do {
-	
+
 	div_n = (range_n[current + 1]  - range_n[current] + DIVIDE_RATE - 1) / DIVIDE_RATE;
-	
+
 	for (xxx = range_n[current], bufferside = 0; xxx < range_n[current + 1]; xxx += div_n, bufferside ++) {
-	  
+
 	  START_RPCC();
-	  
+
 
 	  KERNEL_OPERATION(min_i, MIN(range_n[current + 1] - xxx, div_n), min_l, ALPHA5, ALPHA6,
 			   sa, (FLOAT *)job[current].working[mypos][CACHE_LINE_SIZE * bufferside],
 			   c, ldc, is, xxx);
-	  
+
 	STOP_RPCC(kernel);
 #ifdef TIMING
 	ops += 2 * min_i * (range_n[current + 1]  - range_n[current] - div_n) * min_l;
@@ -508,38 +514,38 @@ static int inner_thread(blas_arg_t *args, BLASLONG *range_m, BLASLONG *range_n,
 	  job[current].working[mypos][CACHE_LINE_SIZE * bufferside] = 0;
 	}
 	}
-	
+
 	current ++;
 	if (current >= args -> nthreads) current = 0;
-	
+
       } while (current != mypos);
-      
+
     } /* end of is */
-    
+
     START_RPCC();
-    
+
     ICOPYR_OPERATION(min_l, min_i, a, lda, ls, m_from, sa);
-    
+
     STOP_RPCC(copy_A);
-    
+
     div_n = (n_to - n_from + DIVIDE_RATE - 1) / DIVIDE_RATE;
-    
+
     for (xxx = n_from, bufferside = 0; xxx < n_to; xxx += div_n, bufferside ++) {
-      
+
       START_RPCC();
-      
+
       /* Make sure if no one is using another buffer */
       for (i = 0; i < args -> nthreads; i++)
 	while (job[mypos].working[i][CACHE_LINE_SIZE * bufferside]) {YIELDING;};
-      
+
       STOP_RPCC(waiting1);
-      
+
       for(jjs = xxx; jjs < MIN(n_to, xxx + div_n); jjs += min_jj){
 	min_jj = MIN(n_to, xxx + div_n) - jjs;
 	if (min_jj > GEMM3M_UNROLL_N) min_jj = GEMM3M_UNROLL_N;
-	
+
 	START_RPCC();
-	
+
 #if   defined(NN) || defined(NT) || defined(TN) || defined(TT)
 	OCOPYR_OPERATION(min_l, min_jj, b, ldb, alpha[0],  alpha[1], ls, jjs, buffer[bufferside] + min_l * (jjs - xxx));
 #elif defined(RR) || defined(RC) || defined(CR) || defined(CC)
@@ -551,43 +557,43 @@ static int inner_thread(blas_arg_t *args, BLASLONG *range_m, BLASLONG *range_n,
 #endif
 
 	STOP_RPCC(copy_B);
-	
+
 	START_RPCC();
-	
+
 	  KERNEL_OPERATION(min_i, min_jj, min_l, ALPHA11, ALPHA12,
 			   sa, buffer[bufferside] + min_l * (jjs - xxx),
 			   c, ldc, m_from, jjs);
-	  
+
 	STOP_RPCC(kernel);
 #ifdef TIMING
 	  ops += 2 * min_i * min_jj * min_l;
 #endif
 
       }
-	
+
       for (i = 0; i < args -> nthreads; i++)
 	job[mypos].working[i][CACHE_LINE_SIZE * bufferside] = (BLASLONG)buffer[bufferside];
       }
-    
+
     current = mypos;
-    
+
     do {
       current ++;
       if (current >= args -> nthreads) current = 0;
-      
+
       div_n = (range_n[current + 1]  - range_n[current] + DIVIDE_RATE - 1) / DIVIDE_RATE;
-      
+
       for (xxx = range_n[current], bufferside = 0; xxx < range_n[current + 1]; xxx += div_n, bufferside ++) {
-	
+
 	if (current != mypos) {
-	  
+
 	  START_RPCC();
-	  
+
 	  /* thread has to wait */
 	  while(job[current].working[mypos][CACHE_LINE_SIZE * bufferside] == 0) {YIELDING;};
-	  
+
 	  STOP_RPCC(waiting2);
-	    
+
 	  START_RPCC();
 
 	  KERNEL_OPERATION(min_i, MIN(range_n[current + 1]  - xxx,  div_n), min_l, ALPHA11, ALPHA12,
@@ -599,41 +605,41 @@ static int inner_thread(blas_arg_t *args, BLASLONG *range_m, BLASLONG *range_n,
 	  ops += 2 * min_i * MIN(range_n[current + 1]  - xxx,  div_n) * min_l;
 #endif
 	}
-	
+
 	if (m_to - m_from == min_i) {
 	  job[current].working[mypos][CACHE_LINE_SIZE * bufferside] = 0;
 	}
       }
     } while (current != mypos);
-    
+
     for(is = m_from + min_i; is < m_to; is += min_i){
       min_i = m_to - is;
       if (min_i >= GEMM3M_P * 2) {
 	min_i = GEMM3M_P;
-      } else 
+      } else
 	if (min_i > GEMM3M_P) {
 	  min_i = ((min_i + 1) / 2 + GEMM3M_UNROLL_M - 1) & ~(GEMM3M_UNROLL_M - 1);
 	}
-      
+
       START_RPCC();
-      
+
       ICOPYR_OPERATION(min_l, min_i, a, lda, ls, is, sa);
-      
+
       STOP_RPCC(copy_A);
-      
+
       current = mypos;
       do {
-	
+
 	div_n = (range_n[current + 1]  - range_n[current] + DIVIDE_RATE - 1) / DIVIDE_RATE;
-	
+
 	for (xxx = range_n[current], bufferside = 0; xxx < range_n[current + 1]; xxx += div_n, bufferside ++) {
-	  
+
 	  START_RPCC();
 
 	  KERNEL_OPERATION(min_i, MIN(range_n[current + 1] - xxx, div_n), min_l, ALPHA11, ALPHA12,
 			   sa, (FLOAT *)job[current].working[mypos][CACHE_LINE_SIZE * bufferside],
 			   c, ldc, is, xxx);
-	  
+
 	STOP_RPCC(kernel);
 #ifdef TIMING
 	ops += 2 * min_i * (range_n[current + 1]  - range_n[current] - div_n) * min_l;
@@ -643,40 +649,40 @@ static int inner_thread(blas_arg_t *args, BLASLONG *range_m, BLASLONG *range_n,
 	  job[current].working[mypos][CACHE_LINE_SIZE * bufferside] = 0;
 	}
 	}
-	
+
 	current ++;
 	if (current >= args -> nthreads) current = 0;
-	
+
       } while (current != mypos);
-      
+
     } /* end of is */
-    
+
 
     START_RPCC();
-    
+
     ICOPYI_OPERATION(min_l, min_i, a, lda, ls, m_from, sa);
-    
+
     STOP_RPCC(copy_A);
-    
+
     div_n = (n_to - n_from + DIVIDE_RATE - 1) / DIVIDE_RATE;
-    
+
     for (xxx = n_from, bufferside = 0; xxx < n_to; xxx += div_n, bufferside ++) {
-      
+
       START_RPCC();
-      
+
       /* Make sure if no one is using another buffer */
       for (i = 0; i < args -> nthreads; i++)
 	while (job[mypos].working[i][CACHE_LINE_SIZE * bufferside]) {YIELDING;};
-      
+
       STOP_RPCC(waiting1);
-      
+
       for(jjs = xxx; jjs < MIN(n_to, xxx + div_n); jjs += min_jj){
 	min_jj = MIN(n_to, xxx + div_n) - jjs;
 	if (min_jj > GEMM3M_UNROLL_N) min_jj = GEMM3M_UNROLL_N;
-	
+
 	START_RPCC();
-	
-#if   defined(NN) || defined(NT) || defined(TN) || defined(TT) 
+
+#if   defined(NN) || defined(NT) || defined(TN) || defined(TT)
 	OCOPYI_OPERATION(min_l, min_jj, b, ldb, alpha[0],  alpha[1], ls, jjs, buffer[bufferside] + min_l * (jjs - xxx));
 #elif defined(RR) || defined(RC) || defined(CR) || defined(CC)
 	OCOPYI_OPERATION(min_l, min_jj, b, ldb, alpha[0], -alpha[1], ls, jjs, buffer[bufferside] + min_l * (jjs - xxx));
@@ -687,43 +693,43 @@ static int inner_thread(blas_arg_t *args, BLASLONG *range_m, BLASLONG *range_n,
 #endif
 
 	STOP_RPCC(copy_B);
-	
+
 	START_RPCC();
-	
+
 	KERNEL_OPERATION(min_i, min_jj, min_l, ALPHA17, ALPHA18,
 			 sa, buffer[bufferside] + min_l * (jjs - xxx),
 			 c, ldc, m_from, jjs);
-	  
+
 	STOP_RPCC(kernel);
 #ifdef TIMING
 	  ops += 2 * min_i * min_jj * min_l;
 #endif
 
       }
-	
+
       for (i = 0; i < args -> nthreads; i++)
 	job[mypos].working[i][CACHE_LINE_SIZE * bufferside] = (BLASLONG)buffer[bufferside];
       }
-    
+
     current = mypos;
-    
+
     do {
       current ++;
       if (current >= args -> nthreads) current = 0;
-      
+
       div_n = (range_n[current + 1]  - range_n[current] + DIVIDE_RATE - 1) / DIVIDE_RATE;
-      
+
       for (xxx = range_n[current], bufferside = 0; xxx < range_n[current + 1]; xxx += div_n, bufferside ++) {
-	
+
 	if (current != mypos) {
-	  
+
 	  START_RPCC();
-	  
+
 	  /* thread has to wait */
 	  while(job[current].working[mypos][CACHE_LINE_SIZE * bufferside] == 0) {YIELDING;};
-	  
+
 	  STOP_RPCC(waiting2);
-	    
+
 	  START_RPCC();
 
 	  KERNEL_OPERATION(min_i, MIN(range_n[current + 1]  - xxx,  div_n), min_l, ALPHA17, ALPHA18,
@@ -735,41 +741,41 @@ static int inner_thread(blas_arg_t *args, BLASLONG *range_m, BLASLONG *range_n,
 	  ops += 2 * min_i * MIN(range_n[current + 1]  - xxx,  div_n) * min_l;
 #endif
 	}
-	
+
 	if (m_to - m_from == min_i) {
 	  job[current].working[mypos][CACHE_LINE_SIZE * bufferside] = 0;
 	}
       }
     } while (current != mypos);
-    
+
     for(is = m_from + min_i; is < m_to; is += min_i){
       min_i = m_to - is;
       if (min_i >= GEMM3M_P * 2) {
 	min_i = GEMM3M_P;
-      } else 
+      } else
 	if (min_i > GEMM3M_P) {
 	  min_i = ((min_i + 1) / 2 + GEMM3M_UNROLL_M - 1) & ~(GEMM3M_UNROLL_M - 1);
 	}
-      
+
       START_RPCC();
-      
+
       ICOPYI_OPERATION(min_l, min_i, a, lda, ls, is, sa);
-      
+
       STOP_RPCC(copy_A);
-      
+
       current = mypos;
       do {
-	
+
 	div_n = (range_n[current + 1]  - range_n[current] + DIVIDE_RATE - 1) / DIVIDE_RATE;
-	
+
 	for (xxx = range_n[current], bufferside = 0; xxx < range_n[current + 1]; xxx += div_n, bufferside ++) {
-	  
+
 	  START_RPCC();
-	  
+
 	  KERNEL_OPERATION(min_i, MIN(range_n[current + 1] - xxx, div_n), min_l, ALPHA17, ALPHA18,
 			   sa, (FLOAT *)job[current].working[mypos][CACHE_LINE_SIZE * bufferside],
 			   c, ldc, is, xxx);
-	  
+
 	STOP_RPCC(kernel);
 #ifdef TIMING
 	ops += 2 * min_i * (range_n[current + 1]  - range_n[current] - div_n) * min_l;
@@ -779,16 +785,16 @@ static int inner_thread(blas_arg_t *args, BLASLONG *range_m, BLASLONG *range_n,
 	  job[current].working[mypos][CACHE_LINE_SIZE * bufferside] = 0;
 	}
 	}
-	
+
 	current ++;
 	if (current >= args -> nthreads) current = 0;
-	
+
       } while (current != mypos);
-      
+
     } /* end of is */
 
   }
-  
+
   START_RPCC();
 
   for (i = 0; i < args -> nthreads; i++) {
@@ -836,7 +842,11 @@ static int gemm_driver(blas_arg_t *args, BLASLONG *range_m, BLASLONG
   BLASLONG range_M[MAX_CPU_NUMBER + 1];
   BLASLONG range_N[MAX_CPU_NUMBER + 1];
 
-  job_t        job[MAX_CPU_NUMBER];
+#ifndef USE_ALLOC_HEAP
+  job_t          job[MAX_CPU_NUMBER];
+#else
+  job_t *        job = NULL;
+#endif
 
   BLASLONG num_cpu_m, num_cpu_n;
 
@@ -852,7 +862,7 @@ static int gemm_driver(blas_arg_t *args, BLASLONG *range_m, BLASLONG
   mode  =  BLAS_DOUBLE  | BLAS_REAL | BLAS_NODE;
 #else
   mode  =  BLAS_SINGLE  | BLAS_REAL | BLAS_NODE;
-#endif  
+#endif
 
   newarg.m        = args -> m;
   newarg.n        = args -> n;
@@ -866,8 +876,17 @@ static int gemm_driver(blas_arg_t *args, BLASLONG *range_m, BLASLONG
   newarg.alpha    = args -> alpha;
   newarg.beta     = args -> beta;
   newarg.nthreads = args -> nthreads;
+
+#ifdef USE_ALLOC_HEAP
+  job = (job_t*)malloc(MAX_CPU_NUMBER * sizeof(job_t));
+  if(job==NULL){
+    fprintf(stderr, "OpenBLAS: malloc failed in %s\n", __func__);
+    exit(1);
+  }
+#endif
+
   newarg.common   = (void *)job;
-    
+
   if (!range_m) {
     range_M[0] = 0;
     m          = args -> m;
@@ -879,7 +898,7 @@ static int gemm_driver(blas_arg_t *args, BLASLONG *range_m, BLASLONG
   num_cpu_m  = 0;
 
   while (m > 0){
-    
+
     width  = blas_quickdivide(m + nthreads - num_cpu_m - 1, nthreads - num_cpu_m);
 
     m -= width;
@@ -900,10 +919,10 @@ static int gemm_driver(blas_arg_t *args, BLASLONG *range_m, BLASLONG
     queue[i].sb      = NULL;
     queue[i].next    = &queue[i + 1];
   }
-  
+
   queue[0].sa = sa;
   queue[0].sb = sb;
-    
+
   if (!range_n) {
     n_from = 0;
     n_to   = args -> n;
@@ -915,23 +934,23 @@ static int gemm_driver(blas_arg_t *args, BLASLONG *range_m, BLASLONG
   for(js = n_from; js < n_to; js += GEMM_R * nthreads){
     n = n_to - js;
     if (n > GEMM_R * nthreads) n = GEMM_R * nthreads;
-    
+
     range_N[0] = js;
 
     num_cpu_n  = 0;
 
     while (n > 0){
-      
+
       width  = blas_quickdivide(n + nthreads - num_cpu_n - 1, nthreads - num_cpu_n);
-      
+
       n -= width;
       if (n < 0) width = width + n;
-      
+
       range_N[num_cpu_n + 1] = range_N[num_cpu_n] + width;
-      
+
       num_cpu_n ++;
     }
-    
+
     for (j = 0; j < num_cpu_m; j++) {
       for (i = 0; i < num_cpu_m; i++) {
 	for (k = 0; k < DIVIDE_RATE; k++) {
@@ -939,12 +958,16 @@ static int gemm_driver(blas_arg_t *args, BLASLONG *range_m, BLASLONG
 	}
       }
     }
-    
+
     queue[num_cpu_m - 1].next = NULL;
-    
+
     exec_blas(num_cpu_m, queue);
   }
 
+#ifdef USE_ALLOC_HEAP
+  free(job);
+#endif
+
   return 0;
 }
 
@@ -955,7 +978,7 @@ int CNAME(blas_arg_t *args, BLASLONG *range_m, BLASLONG *range_n, FLOAT *sa, FLO
   BLASLONG nthreads = args -> nthreads;
   BLASLONG divN, divT;
   int mode;
-  
+
   if (range_m) {
     BLASLONG m_from = *(((BLASLONG *)range_m) + 0);
     BLASLONG m_to   = *(((BLASLONG *)range_m) + 1);
@@ -997,8 +1020,8 @@ int CNAME(blas_arg_t *args, BLASLONG *range_m, BLASLONG *range_n, FLOAT *sa, FLO
     mode  =  BLAS_DOUBLE  | BLAS_COMPLEX;
 #else
     mode  =  BLAS_SINGLE  | BLAS_COMPLEX;
-#endif  
-    
+#endif
+
 #if defined(TN) || defined(TT) || defined(TR) || defined(TC) || \
     defined(CN) || defined(CT) || defined(CR) || defined(CC)
     mode |= (BLAS_TRANSA_T);
@@ -1007,8 +1030,8 @@ int CNAME(blas_arg_t *args, BLASLONG *range_m, BLASLONG *range_n, FLOAT *sa, FLO
     defined(NC) || defined(TC) || defined(RC) || defined(CC)
     mode |= (BLAS_TRANSB_T);
 #endif
-    
-    gemm_thread_n(mode, args, range_m, range_n, gemm_driver, sa, sb, divN); 
+
+    gemm_thread_n(mode, args, range_m, range_n, gemm_driver, sa, sb, divN);
   }
 
   return 0;
