@@ -1,5 +1,5 @@
 /*****************************************************************************
-Copyright (c) 2011,2012 Lab of Parallel Software and Computational Science,ISCAS
+Copyright (c) 2011-2014, The OpenBLAS Project
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
@@ -13,9 +13,10 @@ met:
       notice, this list of conditions and the following disclaimer in
       the documentation and/or other materials provided with the
       distribution.
-   3. Neither the name of the ISCAS nor the names of its contributors may
-      be used to endorse or promote products derived from this software
-      without specific prior written permission.
+   3. Neither the name of the OpenBLAS project nor the names of 
+      its contributors may be used to endorse or promote products 
+      derived from this software without specific prior written 
+      permission.
 
 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
@@ -240,6 +241,7 @@ void set_stack_limit(int limitMB){
 */
 #endif
 
+
 /*
 OpenBLAS uses the numbers of CPU cores in multithreading.
 It can be set by openblas_set_num_threads(int num_threads);
@@ -322,6 +324,23 @@ int blas_get_cpu_number(void){
 }
 #endif
 
+
+int openblas_get_num_procs(void) {
+#ifndef SMP
+  return 1;
+#else
+  return get_num_procs();
+#endif
+}
+
+int openblas_get_num_threads(void) {
+#ifndef SMP
+  return 1;
+#else
+  return blas_get_cpu_number();
+#endif
+}
+
 struct release_t {
   void *address;
   void (*func)(struct release_t *);
@@ -1334,6 +1353,8 @@ void DESTRUCTOR gotoblas_quit(void) {
 
   if (gotoblas_initialized == 0) return;
 
+  blas_shutdown();
+
 #ifdef PROFILE
    moncontrol (0);
 #endif
@@ -1355,8 +1376,6 @@ void DESTRUCTOR gotoblas_quit(void) {
 #ifdef PROFILE
    moncontrol (1);
 #endif
-
-   blas_shutdown();
 }
 
 #if (defined(C_PGI) || (!defined(C_SUN) && defined(F_INTERFACE_SUN))) && (defined(ARCH_X86) || defined(ARCH_X86_64))
